@@ -1,24 +1,33 @@
+from datetime import datetime
 from django.contrib.contenttypes import generic
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.auth.models import User
 from django.db import models
 
+try:
+    from django.utils.timezone import now
+except ImportError:
+    now = datetime.now
+
 from voting.managers import VoteManager
 
+
 SCORES = (
-    (u'+1', +1),
-    (u'-1', -1),
+    (+1, u'+1'),
+    (-1, u'-1'),
 )
 
+
 class Vote(models.Model):
     """
     A vote on an object by a User.
     """
-    user         = models.ForeignKey(User)
+    user = models.ForeignKey(User)
     content_type = models.ForeignKey(ContentType)
-    object_id    = models.PositiveIntegerField()
-    object       = generic.GenericForeignKey('content_type', 'object_id')
-    vote         = models.SmallIntegerField(choices=SCORES)
+    object_id = models.PositiveIntegerField()
+    object = generic.GenericForeignKey('content_type', 'object_id')
+    vote = models.SmallIntegerField(choices=SCORES)
+    time_stamp = models.DateTimeField(editable=False, default=now)
 
     objects = VoteManager()
 
